import SyncStorage from 'sync-storage';
import {Alert} from 'react-native';

const codeMessage = {
    200: '服务器成功返回请求的数据。',
    201: '新建或修改数据成功。',
    202: '一个请求已经进入后台排队（异步任务）。',
    204: '删除数据成功。',
    400: '发出的请求有错误，服务器没有进行新建或修改数据的操作。',
    401: '用户没有权限（令牌、用户名、密码错误）。',
    403: '用户得到授权，但是访问是被禁止的。',
    404: '发出的请求针对的是不存在的记录，服务器没有进行操作。',
    406: '请求的格式不可得。',
    410: '请求的资源被永久删除，且不会再得到的。',
    422: '当创建一个对象时，发生一个验证错误。',
    500: '服务器发生错误，请检查服务器。',
    502: '网关错误。',
    503: '服务不可用，服务器暂时过载或维护。',
    504: '网关超时。',
};

const checkStatus = response => {
    //console.log('************', response, response.status)
    if (response.status >= 200 && response.status < 300) {
        return response;
    } else if (response.status === 400) {
        console.log('************', response.text())
        response.json().then(data => {
            const error = new Error();
            error.name = response.status;
            error.message = data.message;
            throw error;
        });
        return response;
    }

    const errortext = codeMessage[response.status] || response.statusText;
    const error = new Error(errortext);
    error.name = response.status;
    error.response = response;
    throw error;
};

/**
 * Requests a URL, returning a promise.
 *
 * @param  {string} url       The URL we want to request
 * @param  {object} [option] The options we want to pass to "fetch"
 * @return {object}           An object containing either "data" or "err"
 */
export default function request(url, option,) {
    const options = {
        //expirys: true,
        ...option,
    };

    const defaultOptions = {
        //credentials: 'include',
        headers: {},
    };
    const newOptions = {...defaultOptions, ...options};
    if (
        newOptions.method === 'POST' ||
        newOptions.method === 'PUT' ||
        newOptions.method === 'PATCH' ||
        newOptions.method === 'DELETE'
    ) {
        if (!(newOptions.body instanceof FormData)) {
            newOptions.headers = {
                Accept: 'application/json',
                'Content-Type': 'application/x-www-form-urlencoded',
                ...newOptions.headers,
            };
            newOptions.body = JSON.stringify(newOptions.body);
        } else {
            // newOptions.body is FormData
            newOptions.headers = {
                Accept: 'application/json',
                ...newOptions.headers,
            };
        }
    }

    let baseURL = SyncStorage.get('baseURL');
    url = baseURL + url;
    console.log(777777777777777,url)
    let credential = SyncStorage.get('credential');
    if (credential) {
        newOptions.headers = {
            ...newOptions.headers,
            Authorization:`JWT ${credential.token}`,
        };
    }

    return fetch(url, newOptions)
    //.then(checkStatus)
    //.then(response => cachedSave(response, hashcode))
        .then(response => {
            // console.log(99999999,response)
            if (response.status === 400) {
                response.json().then(data => {
                    if (data.message) {
                        Alert.alert('友情提醒', data.message,
                            [
                                {text: '我知道了', style: 'cancel'},
                            ],);
                    }
                });
                return {success: false};
            }
            else if (response.status == 460) {
                SyncStorage.remove('credential');
                Alert.alert(
                    '友情提醒',
                    '登录已过期，请重新登录！',
                    [
                        {text: '我知道了', style: 'cancel'},
                    ],
                );
                return {success: false};
            }
            else if (response.status == 404) {
                // Alert.alert(
                //     '友情提醒',
                //     '当前页面出错了!',
                //     [
                //         {text: '我知道了', style: 'cancel'},
                //     ],
                // );
                return {success: false};
            }
            else if (response.status == 500) {
                Alert.alert(
                    '友情提醒',
                    '当前页面出错了!',
                    [
                        {text: '我知道了', style: 'cancel'},
                    ],
                );
                return {success: false};
            }

            // DELETE and 204 do not return data by default
            // using .json will report an error.
            if (response.status === 204) {
                return response.text();
            }
            const resp = response.json();
            // if (resp.code === 1001){
            //   //  resp.code是未定义，不会执行此处
            //   this.props.dispatch(NavigationActions.navigate({ routeName: 'Login' }));
            //   return;
            // }
            return resp;
        })
        .catch(e => {
            // console.log(88888888,e)
            const status = e.name;
            if (status == 'TypeError') {
                // Alert.alert(
                //     '友情提醒',
                //     '服务器走丢了，请稍后重试！',
                //     [
                //         {text: '我知道了', style: 'cancel'},
                //     ],
                // );
            }
            else if (status == 400) {
                Alert.alert(
                    '友情提醒',
                    e.message,
                    [
                        {text: '我知道了', style: 'cancel'},
                    ],
                );
            }
            else if (status == 404) {
                Alert.alert(
                    '友情提醒',
                    '请求的操作不存在！',
                    [
                        {text: '我知道了', style: 'cancel'},
                    ],
                );
            }
            else if (status == 500) {
                Alert.alert(
                    '友情提醒',
                    '远程错误！',
                    [
                        {text: '我知道了', style: 'cancel'},
                    ],
                );
            }
            return {success: false};
        });
}
